#### options:
# Use the following --with/--without <option> switches to control how the
# package will be built:
# 
# modular_x:   modular X dependencies
# lcms:        lcms support
# python:      python support
# mp:          multi processor support
# static:      build static libraries
# print:       build the print plugin (if you don't build it externally)
# gutenprint:  require gutenprint-plugin (instead of gimp-print-plugin) if
#              internal print plugin isn't built
# convenience: install convenience symlinks

%if 0%{?fedora}%{?rhel} == 0 || 0%{?fedora} >= 5 || 0%{?rhel} >= 5
%bcond_without modular_x
%bcond_without lcms
%else
%bcond_with modular_x
%bcond_with lcms
%endif

%if 0%{?fedora}%{?rhel} == 0 || 0%{?fedora} >= 7 || 0%{?rhel} >= 6
%bcond_without gutenprint
%bcond_without xdg_open
%else
%bcond_with gutenprint
%bcond_with xdg_open
%endif

%if 0%{?fedora}%{?rhel} == 0 || 0%{?fedora} >= 8 || 0%{?rhel} >= 6
%bcond_without print
%else
%bcond_with print
%endif

%bcond_without python
%bcond_without mp
%bcond_without convenience
%bcond_with static

#
#

Summary:        GNU Image Manipulation Program
Name:           gimp
Version:        2.4.5
%define binver 2.4
%define gimp_lang_ver 20
%define interfacever 2.0
%define age 0
%define minorver 400
%define microver %(ver=%{version}; echo ${ver##*.*.})
Release:        1%{?dist}
Epoch:          2
License:        GPLv2+
Group:          Applications/Multimedia
URL:            http://www.gimp.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-root-%(%__id_u -n)
Obsoletes:      gimp2 gimp-beta <= %{?epoch:%{epoch}:}2.4
Obsoletes:      gimp-perl < 2:2.0
BuildRequires:  alsa-lib-devel >= 1.0.0
BuildRequires:  curl-devel >= 7.15.1
BuildRequires:  dbus-glib-devel >= 0.70
BuildRequires:  fontconfig-devel >= 2.2.0
BuildRequires:  freetype-devel >= 2.1.7
BuildRequires:  glib2-devel >= 2.12.3
BuildRequires:  gnome-keyring-devel >= 0.4.5
BuildRequires:  gnome-vfs2-devel >= 2.10.0
BuildRequires:  gtk2-devel >= 2.10.13
BuildRequires:  gtk-doc >= 1.0
BuildRequires:  gtkhtml2-devel >= 2.0.0
BuildRequires:  hal-devel >= 0.5.7
BuildRequires:  libexif-devel >= 0.6.15
BuildRequires:  libgnomeui-devel >= 2.10.0
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  libpng-devel
BuildRequires:  librsvg2-devel >= 2.14.0
BuildRequires:  libtiff-devel
BuildRequires:  libwmf-devel >= 0.2.8
BuildRequires:  pango-devel >= 1.12.2
BuildRequires:  poppler-devel >= 0.4.1
BuildRequires:  python-devel
BuildRequires:  pygtk2-devel >= 2.10.4
BuildRequires:  pygobject2-devel
%if %{with modular_x}
BuildRequires:  libX11-devel
BuildRequires:  libXmu-devel
%else
BuildRequires:  xorg-x11-devel
%endif
BuildRequires:  sed
BuildRequires:  intltool
BuildRequires:  gettext
BuildRequires:  findutils
%if %{with lcms}
BuildRequires:  lcms-devel
%endif

Requires:       gimp-libs-%{_arch} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires:       desktop-file-utils >= 0.9
Requires:       glib2 >= 2.12.3
Requires:       gtk2 >= 2.10.13
Requires:       pango >= 1.12.2
Requires:       freetype >= 2.1.7
Requires:       fontconfig >= 2.2.0
%if ! %{with print}
%if %{with gutenprint}
Requires:       gutenprint-plugin
%else
Requires:       gimp-print-plugin
%endif
%endif
Requires(post): /usr/bin/update-desktop-database
Requires(postun):   /usr/bin/update-desktop-database
Requires:       hicolor-icon-theme
%if %{with xdg_open}
Requires:       xdg-utils
%else
Requires:       htmlview
%endif

Source0:        ftp://ftp.gimp.org/pub/gimp/v%{binver}/gimp-%{version}.tar.bz2
Source1:        gimp-plugin-mgr.in
Patch0:         gimp-2.4.0-htmlview.patch
Patch1:         gimp-2.4.0-xdg-open.patch

%description
GIMP (GNU Image Manipulation Program) is a powerful image composition and
editing program, which can be extremely useful for creating logos and other
graphics for webpages. GIMP has many of the tools and filters you would expect
to find in similar commercial offerings, and some interesting extras as well.
GIMP provides a large image manipulation toolbox, including channel operations
and layers, effects, sub-pixel imaging and anti-aliasing, and conversions, all
with multi-level undo.

%package libs
Summary:        GIMP libraries
Group:          System Environment/Libraries
License:        LGPLv2+
Provides:       gimp-libs-%{_arch} = %{?epoch:%{epoch}:}%{version}-%{release}

%description libs
The gimp-libs package contains shared libraries needed for the GNU Image
Manipulation Program (GIMP).

%package devel
Summary:        GIMP plugin and extension development kit
Group:          Applications/Multimedia
License:        LGPLv2+
Requires:       gimp-libs-%{_arch} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires:       gtk2-devel
Requires:       glib2-devel
Requires:       pkgconfig
Obsoletes:      gimp2-devel gimp-beta-devel <= %{?epoch:%{epoch}:}2.4

%description devel
The gimp-devel package contains the static libraries and header files
for writing GNU Image Manipulation Program (GIMP) plug-ins and
extensions.

%prep
cat << EOF

Build options:
modular X:                                %{with modular_x}
LCMS support:                             %{with lcms}
Python support:                           %{with python}
MP support:                               %{with mp}
build static libs:                        %{with static}
build internal print plugin:              %{with print}
include convenience symlinks:             %{with convenience}
build the print plugin:                   %{with print}
%if ! %{with print}
prefer gutenprint over (external) gimp-print plugin:
                                          %{with gutenprint}
%endif
use xdg-open instead of htmlview:         %{with xdg_open}


EOF

%setup -q -n gimp-%{version}
%if %{with xdg_open}
%patch1 -p1 -b .xdg-open
%else
%patch0 -p1 -b .htmlview
%endif

%build
LIBAA="disable"; export LIBAA
if [ ! -f configure ]; then
  ./autogen.sh --quiet $MYARCH_FLAGS --prefix=%{_prefix}
fi
CFLAGS="%optflags -fomit-frame-pointer" \
%configure \
	--disable-perl \
%if %{with python}
	--enable-python \
%else
	--disable-python \
%endif
%if %{with mp}
	--enable-mp \
%else
	--disable-mp \
%endif
%if %{with static}
	--enable-static \
%else
	--disable-static \
%endif
%if %{with print}
	--with-print \
%else
	--without-print \
%endif
%if %{with lcms}
	--with-lcms \
%else
	--without-lcms \
%endif
    --enable-gimp-console \
    --without-aa \
%ifos linux
    --with-linux-input \
%endif
    --with-libtiff --with-libjpeg --with-libpng --with-libmng --with-libexif \
    --with-gtkhtml2 --with-librsvg --with-poppler --with-gnomevfs --with-alsa \
    --with-dbus --with-script-fu

make %{?_smp_mflags}

# convenience stuff for external plugins (e.g. xsane)
sed -e 's|@GIMPTOOL@|%{_bindir}/gimptool-%{interfacever}|g' < %{SOURCE1} > gimp-plugin-mgr

%install
rm -rf %{buildroot}

# makeinstall macro won't work here - libexec is overriden
make DESTDIR=%{buildroot} install

%ifos linux
# remove .la files
find %buildroot -name \*.la -exec %__rm -f {} \;
%endif

#
# Plugins and modules change often (grab the executeable ones)
#
echo "%defattr (-, root, root)" > gimp-plugin-files
find %{buildroot}%{_libdir}/gimp/%{interfacever} -type f | sed "s@^%{buildroot}@@g" | grep -v '\.a$' >> gimp-plugin-files

# .pyc and .pyo files don't exist yet
grep "\.py$" gimp-plugin-files > gimp-plugin-files-py
for file in $(cat gimp-plugin-files-py); do
    for newfile in ${file}c ${file}o; do
        fgrep -q -x "$newfile" gimp-plugin-files || echo "$newfile"
    done
done >> gimp-plugin-files

%if %{with static}
echo "%defattr (-, root, root)" > gimp-static-files
find %{buildroot}%{_libdir}/gimp/%{interfacever} -type f | sed "s@^%{buildroot}@@g" | grep '\.a$' >> gimp-static-files
%endif

#
# Auto detect the lang files.
#
%find_lang gimp%{gimp_lang_ver}
%find_lang gimp%{gimp_lang_ver}-std-plug-ins
%find_lang gimp%{gimp_lang_ver}-script-fu
%find_lang gimp%{gimp_lang_ver}-libgimp
%find_lang gimp%{gimp_lang_ver}-tips
%find_lang gimp%{gimp_lang_ver}-python

cat gimp%{gimp_lang_ver}.lang gimp%{gimp_lang_ver}-std-plug-ins.lang gimp%{gimp_lang_ver}-script-fu.lang gimp%{gimp_lang_ver}-libgimp.lang gimp%{gimp_lang_ver}-tips.lang gimp%{gimp_lang_ver}-python.lang > gimp-all.lang

#
# Build the master filelists generated from the above mess.
#
cat gimp-plugin-files gimp-all.lang > gimp.files

%if %{with convenience}
# install convenience symlinks
ln -snf gimp-%{binver} %{buildroot}%{_bindir}/gimp
ln -snf gimp-%{binver}.1 %{buildroot}%{_mandir}/man1/gimp.1
ln -snf gimp-console-%{binver} %{buildroot}/%{_bindir}/gimp-console
ln -snf gimp-console-%{binver}.1 %{buildroot}/%{_mandir}/man1/gimp-console.1
ln -snf gimp-remote-%{binver} %{buildroot}%{_bindir}/gimp-remote
ln -snf gimp-remote-%{binver}.1 %{buildroot}%{_mandir}/man1/gimp-remote.1
ln -snf gimptool-%{interfacever} %{buildroot}%{_bindir}/gimptool
ln -snf gimptool-%{interfacever}.1 %{buildroot}%{_mandir}/man1/gimptool.1
ln -snf gimprc-%{binver}.5 %{buildroot}/%{_mandir}/man5/gimprc.5
%endif

# convenience stuff for external plugins (e.g. xsane)
mkdir -p %{buildroot}%{_sysconfdir}/gimp/plugins.d
mkdir -p %{buildroot}%{_sbindir}
install -m 0755 gimp-plugin-mgr %{buildroot}%{_sbindir}/gimp-plugin-mgr

%clean
rm -rf %{buildroot}

%pre
# First, remove old symlinks which are possibly in an old location (before a
# major version update)
if [ -x "%{_sbindir}/gimp-plugin-mgr" ]; then
    %{_sbindir}/gimp-plugin-mgr --uninstall '*' || :
fi

%post
/usr/bin/update-desktop-database %{_datadir}/applications
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi
# Then re-add the symlinks
%{_sbindir}/gimp-plugin-mgr --install '*' || :

%preun
# Only delete symlinks when uninstalling
if [ "$1" = "0" ]; then
    %{_sbindir}/gimp-plugin-mgr --uninstall '*' || :
fi

%postun
if [ "$1" = "0" ]; then
    /usr/bin/update-desktop-database %{_datadir}/applications || :
fi
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files -f gimp.files
%defattr(-, root, root, 0755)
%doc AUTHORS COPYING ChangeLog NEWS README
%doc docs/*.xcf*
%{_datadir}/applications/*.desktop
%{_datadir}/application-registry/*.applications
%{_datadir}/mime-info/*.keys

%dir %{_datadir}/gimp
%dir %{_datadir}/gimp/%{interfacever}
%{_datadir}/gimp/%{interfacever}/tips/
%{_datadir}/gimp/%{interfacever}/menus/
%dir %{_libdir}/gimp
%dir %{_libdir}/gimp/%{interfacever}
%dir %{_libdir}/gimp/%{interfacever}/environ
#%dir %{_libdir}/gimp/%{interfacever}/fonts
%dir %{_libdir}/gimp/%{interfacever}/modules
%dir %{_libdir}/gimp/%{interfacever}/plug-ins
%dir %{_libdir}/gimp/%{interfacever}/python
#%dir %{_libdir}/gimp/%{interfacever}/tool-plug-ins

%{_datadir}/gimp/%{interfacever}/brushes/
%{_datadir}/gimp/%{interfacever}/fractalexplorer/
%{_datadir}/gimp/%{interfacever}/gfig/
%{_datadir}/gimp/%{interfacever}/gflare/
%{_datadir}/gimp/%{interfacever}/gimpressionist/
%{_datadir}/gimp/%{interfacever}/gradients/
# %{_datadir}/gimp/%{interfacever}/help/
%{_datadir}/gimp/%{interfacever}/images/
%{_datadir}/gimp/%{interfacever}/palettes/
%{_datadir}/gimp/%{interfacever}/patterns/
%{_datadir}/gimp/%{interfacever}/scripts/
%{_datadir}/gimp/%{interfacever}/themes/

%dir %{_sysconfdir}/gimp
%dir %{_sysconfdir}/gimp/plugins.d
%dir %{_sysconfdir}/gimp/%{interfacever}
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/controllerrc
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/gimprc
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/gtkrc
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/unitrc
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/ps-menurc
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/sessionrc
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/templaterc
%config(noreplace) %{_sysconfdir}/gimp/%{interfacever}/menurc

%{_bindir}/gimp-%{binver}
%{_bindir}/gimp-remote-%{binver}
%{_bindir}/gimptool-%{interfacever}
%{_bindir}/gimp-console-%{binver}
%{_sbindir}/gimp-plugin-mgr

%if %{with convenience}
%{_bindir}/gimp
%{_bindir}/gimp-remote
%{_bindir}/gimptool
%{_bindir}/gimp-console
%endif

%{_mandir}/man1/gimp-%{binver}.1*
%{_mandir}/man1/gimp-remote-%{binver}.1*
%{_mandir}/man1/gimptool-%{interfacever}.1*
%{_mandir}/man1/gimp-console-%{binver}.1*
%{_mandir}/man5/gimprc-%{binver}.5*

%if %{with convenience}
%{_mandir}/man1/gimp.1*
%{_mandir}/man1/gimp-remote.1*
%{_mandir}/man1/gimptool.1*
%{_mandir}/man1/gimp-console.1*
%{_mandir}/man5/gimprc.5*
%endif

%{_datadir}/icons/hicolor/*/apps/gimp.png
%{_datadir}/icons/hicolor/scalable/apps/gimp.svg

%files libs
%defattr(-, root, root, 0755)
%{_libdir}/libgimp-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimp-%{interfacever}.so.%{age}
%{_libdir}/libgimpbase-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpbase-%{interfacever}.so.%{age}
%{_libdir}/libgimpcolor-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpcolor-%{interfacever}.so.%{age}
%{_libdir}/libgimpconfig-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpconfig-%{interfacever}.so.%{age}
%{_libdir}/libgimpmath-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpmath-%{interfacever}.so.%{age}
%{_libdir}/libgimpmodule-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpmodule-%{interfacever}.so.%{age}
%{_libdir}/libgimpthumb-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpthumb-%{interfacever}.so.%{age}
%{_libdir}/libgimpui-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpui-%{interfacever}.so.%{age}
%{_libdir}/libgimpwidgets-%{interfacever}.so.%{age}.%{minorver}.%{microver}
%{_libdir}/libgimpwidgets-%{interfacever}.so.%{age}

%if %{with static}
%files devel -f gimp-static-files
%else
%files devel
%endif
%defattr (-, root, root, 0755)
%doc HACKING README.i18n
%doc %{_datadir}/gtk-doc/*

%{_libdir}/*.so
%dir %{_libdir}/gimp
%dir %{_libdir}/gimp/%{interfacever}
%dir %{_libdir}/gimp/%{interfacever}/modules
%ifnos linux
%{_libdir}/*.la
%{_libdir}/gimp/%{interfacever}/modules/*.la
%endif
%{_datadir}/aclocal/*.m4
%{_includedir}/gimp-%{interfacever}
%{_libdir}/pkgconfig/*

%changelog
* Mon Mar 03 2008 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.5-1
- version 2.4.5

  Changes in GIMP 2.4.5
  =====================

  - fixed a regression introduced by the brush cursor optimization
    (bug #514309)
  - fixed bug in transform tool preview (bug #340965)
  - fixed PSD export of images with layer masks
  - fixed base64 encoding routine of the Mail plug-in
  - use the correct background color when creating a new image
    (bug #514082)
  - explicitly link libgimpthumb with GLib (bug #515566)
  - improved selection of the font sample string (bug #514021)
  - unified handling of "Enter" and "Space" keysyms (bug #516544)
  - fixed bug in the Glossy script when used with a pattern (bug #517285)
  - correctly record dimensions in Exif data when saving as JPEG
    (bug #517077)
  - fixed sensitivity of plug-in menu items (bug #517683)
  - fixed potential crashes in Wind, Warp, Small Tiles and Apply Canvas
    plug-ins (bug #516369)
  - added default keyboard shortcut for "Paste As New Image"
    (Ctrl-Shift-V)
  - added default keyboard shortcut for "Copy Visible" (Ctrl-Shift-C)
  - fixed missing preview update in Curves tool (bug #518012)
  - fixed a bug in the Frosty Logo script (bug #472316)
  - fixed backward transformations using the PDB (bug #518910)
  - translation fixes and updates (de, eu, eo, fr, he, hu, it, ja, ko)

* Mon Feb 18 2008 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.4-2
- let gimp-libs provide, gimp and gimp-devel require "gimp-libs-%%{_arch}"
  (#433195)

* Wed Jan 30 2008 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.4-1
- version 2.4.4

  Changes in GIMP 2.4.4
  =====================

  - fixed typo in stock icon name
  - fixed handling of PSD files with empty layer names (bug #504149)
  - merged TinyScheme bug-fixes
  - removed duplicate entry from Tango palette
  - corrected parameter range in Chip Away script (bug #506110)
  - reduced redraw priority and speed of the marching ants (bug #479875)
  - fixed out-of-bounds array access in Convolution Matrix plug-in
  - reduced rounding errors in Convolution Matrix plug-in (bug #508114)
  - fixed potential crash on missing CMYK color profile
  - fixed crash in Bumpmap plug-in when called from some scripts (bug #509608)
  - Equalize should not equalise the alpha channel (bug #510210)
  - increased the number of points the ImageMap plug-in can handle (bug #511072)
  - adjusted the priority of the projection renderer (bug #511214)
  - smooth the brush mask to get a simpler cursor boundary (bug #304798)
  - show the selection even if the image window is invisible (bug #505758)
  - allow to commit a pending rectangular selection using Enter (bug #511599)
  - fixed bug in image dirty state logic (bug #509822)
  - improved GIMPressionist preformance and reduced startup time (bug #512126)
  - fixed a crash in the Convert to Color Profile plug-in (bug #512529)
  - merged some other minor fixes from trunk
  - translation updates (de, it, lt, ru, sv, uk)

* Mon Jan 28 2008 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.3-2
- don't package static libraries (#430330)
- use %%bcond_... macros for package options

* Mon Dec 17 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.3-1
- version 2.4.3

  Changes in GIMP 2.4.3
  =====================

  - avoid filename encoding problems in the WMF import plug-in (bug #499329)
  - fixed horizontal flipping of linked layers (bug #499161)
  - fixed a missing update in the Lighting plug-in UI (bug #500317)
  - fixed a potential crash in the projection code (bug #500178)
  - fixed a minor Makefile issue (bug #500826)
  - removed some pointless warnings from the JPEG and TIFF load plug-ins
  - fixed size calculation for the image size warning dialog (bug #329468)
  - fixed loading of tool options for the rectangle tools (bug #498948)
  - push/pop a context in the Fog filter
  - fixed potential crashes in the Python binding
  - corrected grid drawing with non-integer spacing (bug #502374)
  - fixed grid snapping for coordinates less than the grid offset
  - made the healing brush work properly when dragged (bug #492575)
  - update tool state when a device change happens (bug #493176)
  - improved validation of strings sent over the wire (bug #498207)
  - fixed integer check in Script-Fu (bug #498207)
  - fixed potential out-of-memory problem in Script-Fu
  - translation updates (ca, cs, de, gl, it, ko, lt, sv, uk)

* Wed Nov 28 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.2-2
- fix typo to build internal print plugin from F8 onwards (#401931)

* Thu Nov 22 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.2-1
- version 2.4.2

  Changes in GIMP 2.4.2
  =====================

  - removed broken and useless HSV Graph script (bug #491311)
  - update the histogram when a color correction tool is cancelled (bug #493639)
  - fixed a crash with certain plug-in or script descriptions (bug #492718)
  - corrected a tooltip (bug #495564)
  - fixed a crash when GIMP is run without any modules (bug #495863)
  - fixed error handling in the TIFF plug-in
  - fixed a problem with Sample points
  - fixed a crash when merging layers in indexed image (bug #495990)
  - update the histogram when painting (bug #494049)
  - fixed another problem with merge operations on indexed images (bug #496437)
  - fixed crash in TIFF plug-in when saving indexed images (bug #497103)
  - changed defaults so that a system monitor profile is only used when the
    user explicitely enabled this feature (bug #496890)
  - fixed endless loop when running equalize on transparent areas (bug #497291)
  - fixed heap corruption in GimpColorScale widget that caused a crash in the
    Compose plug-in (bug #399484)
  - fixed use of background color in Particle Trace script (bug #498282)
  - set the image menu insensitive when there's no image opened (bug #498511)
  - translation updates (ca, et, it, lt, pt, pt_BR, sr, sv)

* Wed Oct 31 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.1-1
- version 2.4.1

  Changes in GIMP 2.4.1
  =====================

  - fixed a minor display rendering problem
  - improved the workaround for broken graphics card drivers (bug #421466)
  - fixed a crash with broken scripts and plug-ins (bug #490055)
  - fixed potential syntax error in configure script (bug #490068)
  - fixed parsing of floating point numbers in Script-Fu (bug #490198)
  - fixed potential crash when converting an indexed image to RGB (bug #490048)
  - update the histogram while doing color corrections (bug #490182)
  - fixed another crash with broken plug-ins (bug #490617).
  - translation updates

* Mon Oct 29 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-4
- use either htmlview or xdg-open in documentation instead of firefox (#355801)

* Thu Oct 25 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-3
- add epoch to obsoletes

* Wed Oct 24 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-1
- version 2.4.0
- use xdg-open instead of htmlview on Fedora 7 and later
- change hicolor-icon-theme requirement to be "uncolored" (without
  "(post)"/"(postun)")
- don't let gtk-update-icon-cache fail scriptlets

* Fri Sep 07 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-0.rc3.2
- build internal print plugin, don't require external print plugins on Fedora 8
  and later

* Fri Sep 07 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-0.rc3.1
- version 2.4.0-rc3

* Fri Sep 07 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-0.rc2.2
- rebuild to pick up new version of poppler

* Tue Sep 04 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-0.rc2.1
- version 2.4.0-rc2

* Thu Aug 16 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.4.0-0.rc1.1
- version 2.4.0-rc1
- change license tags to GPLv2+ (main app), LGPLv2+ (libs and devel)
- drop libXt-devel build requirement
- build-require pygobject2-devel directly
- don't let %%postun fail
- remove obsolete buildroot, gimphelpmissing, icontheme, gifload, gimptool
  patches
- update htmlview patch
- use more distinct build root
- use %%buildroot consistently
- explicitely enable configure options
- more versionized build requirements
- don't rebuild autofoo files
- reformat spec file a bit

* Fri Jul 13 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.17-1
- version 2.2.17

  Bugs fixed in GIMP 2.2.17
  =========================

  - fixed regression in PSD load plug-in (bug #456042)
  - fixed crash when loading a corrupt PSD file (bug #327444)
  - work around for Pango appending " Not-Rotated" to font names 

* Wed Jul 11 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.16-2
- don't let gimp-plugin-mgr --uninstall fail %%post scriptlet

* Mon Jul 09 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.16-1
- version 2.2.16

  Bugs fixed in GIMP 2.2.16
  =========================

  - improved input value validation in several file plug-ins (bug #453973)
  - improved handling of corrupt or invalid XCF files
  - guard against integer overflows in several file plug-ins (bug #451379)
  - fixed handling of background alpha channel in XCF files (bug #443097)
  - improved forward compatibility of the config parser
  - fixed crash when previewing some animated brushes (bug #446005)

- remove obsolete psd-invalid-dimensions patch

* Wed Jun 27 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.15-3
- refuse to open PSD files with insanely large dimensions (#244400, fix by Sven
  Neumann)

* Wed Jun 13 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.15-2
- require gutenprint-plugin or gimp-print-plugin (#243593)

* Thu May 31 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.15-1
- version 2.2.15

  Bugs fixed in GIMP 2.2.15
  =========================
  
  - fixed parsing of GFig files with CRLF line endings (bug #346988)
  - guard against a possible stack overflow in the Sunras loader (bug #433902)
  - fixed definition of datarootdir in gimptool-2.0 (bug #436386)
  - fixed Perspective tool crash on Mac OS X (bug #349483)
  - fixed area resizing in the Image Map plug-in (bug #439222)
  - added missing library in gimptool-2.0 --libs output
  - added new localizations: Occitan and Persian

- remove obsolete sunras-overflow patch

* Tue May 01 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.14-5
- don't let gimp-plugin-mgr --uninstall fail %%pre/%%preun scriptlets (#238337)

* Mon Apr 30 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.14-4
- fix plugin symlinks handling better (#238337)

* Mon Apr 30 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.14-3
- don't erroneously delete symlinks to external plugins when updating (#238337)

* Mon Apr 30 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.14-2
- avoid buffer overflow in sunras plugin (#238422)

* Tue Apr 24 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.14-1
- version 2.2.14
  
  Bugs fixed in GIMP 2.2.14
  =========================
  
  - avoid crashing on newer versions of the winicon format (bug #352899)
  - fixed crash in Postscript plug-in (bug #353381)
  - fixed handling of TABs in the text tool (bug #353132)
  - fixed bug in Depth Merge plug-in (bug #355219)
  - fixed bug in GimpDrawablePreview widget (bug #353639)
  - fixed bug in Line Nove script (bug #357433)
  - fixed bug in Ripple plug-in (bug #357431)
  - save locale independent files from Fractal Explorer plug-in (bug #360095)
  - fixed bug in Super Nova plug-in (bug #340073)
  - be more robust against broken XCF files (bug #357809)
  - fixed drawing issues in Image Map plug-in (bug #311621)
  - fixed smoothing option in Fractal Explorer plug-in (bug #372671)
  - load channels in the proper order when opening an XCF file (bug #378003)
  - deal with floating selections in the Burn-In Animation script (bug #384096)
  - fixed clipping in the GimpPreviewArea widget (bug #392692)
  - fixed a potential crash in gimp-remote (bug #392111)
  - work around a file-chooser problem on Windows (bug #398726)
  - fixed markup of the gimp(1) manual page (bug #401145)
  - fixed the fix for the right-to-left layout in layers dialog (bug #348347)
  - fixed PSD save plug-in on 64bit architectures (bug #335130)
  - added missing dependency in gimpui-2.0.pc file (bug #356394)
  - fixed a crash in the PSD save plug-in (bug #395385)
  - improved robustness of transform tool preview code (bug #420595)
  - improved forward compatibility of XCF loader (bug #316207)
  - don't crash in the Compressor plug-in if files can't be opened (bug #422444)
  - fixed sensitivity of input fields in the Lighting plug-in (bug #359833)

- don't BuildRequire gimp-print/gutenprint anymore

* Mon Mar 26 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.13-3
- use gutenprint per default for current development/future distribution
  versions (Fedora >= 7, RHEL >= 6)

* Mon Mar 26 2007 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.13-2
- own used directories in gimp-devel (#233794)

* Wed Feb 21 2007 Nils Philippsen <nphilipp@redhat.com>
- s/%%redhat/%%rhel/g

* Wed Feb 07 2007 Nils Philippsen <nphilipp@redhat.com>
- really change defaults for use of modular X and lcms (#224156)

* Thu Feb 01 2007 Nils Philippsen <nphilipp@redhat.com>
- change defaults for use of modular X and lcms (#224156)

* Fri Aug 25 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.13-1
- version 2.2.13
- remove obsolete filename patch

* Thu Aug 17 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.12-5
- don't barf on empty /etc/gimp/plugins.d (#202808)

* Wed Aug 16 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.12-4
- revamp scheme for integrating external plugins (#202545)

* Wed Aug 02 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.12-3
- allow spaces in filenames when saving (#200888, patch by Michael Natterer)

* Tue Jul 18 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.12-2
- split off libraries into gimp-libs to allow multilib installations
- remove pre-release cruft

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2:2.2.12-1.1
- rebuild

* Mon Jul 10 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.12-1
- version 2.2.12
- use %%dist/%%fedora/%%redhat
- remove obsolete gcc4, libpng patches
- show build options in %%prep
- require gettext for building

* Wed May 31 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.11-5
- cope with pygobject2/-devel being split off (#193368)

* Tue May 09 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.11-4
- don't use long deprecated libpng API (#191027, patch by Manish Singh)

* Thu Apr 20 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.11-3
- only use pkgconfig if needed in gimptool, require pkgconfig in devel
  subpackage (#189314, #189371)

* Wed Apr 19 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.11-2
- require pkgconfig (#189314)

* Tue Apr 18 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.11-1
- version 2.2.11

* Fri Mar 03 2006 Nils Philippsen <nphilipp@redhat.com> - 2:2.2.10-4
- use htmlview as default web browser (#183730, patch by Ben Levenson)
- require hicolor-icon-theme (#182784, #182785)

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 2:2.2.10-2.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 2:2.2.10-2.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Tue Jan 10 2006 Nils Philippsen <nphilipp@redhat.com>
- rebuild with lcms

* Thu Dec 29 2005 Nils Philippsen <nphilipp@redhat.com> - 2.2.10
- version 2.2.10

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Fri Dec 09 2005 Nils Philippsen <nphilipp@redhat.com>
- build with -fomit-frame-pointer to let assembly build with gcc 4.1

* Fri Dec 02 2005 Nils Philippsen <nphilipp@redhat.com>
- build with gcc 4.1

* Tue Nov 08 2005 Nils Philippsen <nphilipp@redhat.com>
- don't include .la files (#172626)
- require findutils for building

* Wed Nov 02 2005 Nils Philippsen <nphilipp@redhat.com> - 2.2.9
- version 2.2.9
- first attempt at dealing with modular X

* Tue Aug 16 2005 Nils Philippsen <nphilipp@redhat.com>
- rebuild

* Thu Jul 28 2005 Nils Philippsen <nphilipp@redhat.com>
- fix gimptool manpage symlink

* Mon Jul 25 2005 Nils Philippsen <nphilipp@redhat.com> - 2.2.8
- version 2.2.8
- clean up file list generation a bit
- gimptool manpage is in section 1 not 5
- list auto-generated .pyc and .pyo files

* Fri May 13 2005 Nils Philippsen <nphilipp@redhat.com>
- fix inline asm of MMX/SSE optimizations instead of using -mmmx and the like

* Fri May 13 2005 Nils Philippsen <nphilipp@redhat.com>
- fix cpuinstructionset patch so that it actually uses CPU-specific
  optimizations

* Wed May 11 2005 Nils Philippsen <nphilipp@redhat.com>
- use -mmmx/sse/sse2/... only for the relevant source files so that extended
  instruction sets only get used on suitable CPUs (#157409)

* Mon May 09 2005 Nils Philippsen <nphilipp@redhat.com>
- version 2.2.7, fixes bug in SSE2 assembly for Lighten Only layer mode
  (#145771) and various other bugs
- on x86 and x86_64, use -msse and -msse2 to accomodate newer compilers

* Wed Apr 27 2005 Jeremy Katz <katzj@redhat.com> - 2:2.2.6-2
- silence %%post

* Mon Apr 11 2005 Nils Philippsen <nphilipp@redhat.com>
- version 2.2.6

* Tue Mar 29 2005 Nils Philippsen <nphilipp@redhat.com>
- revert gtk requirement change

* Mon Mar 28 2005 Matthias Clasen <mclasen@redhat.com>
- Rebuild against newer libexif

* Mon Mar 28 2005 Christopher Aillon <caillon@redhat.com>
- rebuilt

* Fri Mar 25 2005 Christopher Aillon <caillon@redhat.com>
- Update the GTK+ theme icon cache on (un)install

* Tue Mar 22 2005 Nils Philippsen <nphilipp@redhat.com>
- install convenience symlinks for man pages

* Fri Mar 11 2005 Nils Philippsen <nphilipp@redhat.com>
- don't refer to freefonts and sharefonts in %%description

* Wed Mar 09 2005 Nils Philippsen <nphilipp@redhat.com>
- prevent gifload plugin from crashing when loading files with bogus frame size
  (#150677, #150678)

* Wed Mar 02 2005 Nils Philippsen <nphilipp@redhat.com>
- don't barf when building with gcc 4.0

* Wed Feb 23 2005 Nils Philippsen <nphilipp@redhat.com>
- version 2.2.4
- require newer versions of gtk2 (#143840), glib2 and pango

* Sat Jan 29 2005 Nils Philippsen <nphilipp@redhat.com>
- make desktop icon themeable (#146486)

* Mon Jan 24 2005 Nils Philippsen <nphilipp@redhat.com>
- version 2.2.3
- remove exifmarkerlength patch (improved version applied upstream)

* Mon Jan 17 2005 Nils Philippsen <nphilipp@redhat.com>
- clip thumbnail quality at 75 and don't barf on saving images at quality 0
  (fix patch for #145100)

* Fri Jan 14 2005 Nils Philippsen <nphilipp@redhat.com>
- avoid writing excessively long EXIF markers (#145100)

* Tue Jan 11 2005 Nils Philippsen <nphilipp@redhat.com>
- version 2.2.2
- autogenerate %%microver

* Wed Dec 29 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.2.1
- pygimp-logo.png included in tarball again

* Mon Dec 20 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.2.0
- include pygimp-logo.png missing from tarball

* Fri Dec 10 2004 Nils Philippsen <nphilipp@redhat.com>
- use xsane plugin (un)install script if available

* Mon Nov 22 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.2-pre2

* Thu Nov 18 2004 Nils Philippsen <nphilipp@redhat.com>
- obsolete fixed gimp-perl version to be able to reintroduce it at a
  later point
- use correct dir in source URL

* Wed Nov 03 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.2-pre1

* Sun Oct 24 2004 Nils Philippsen <nphilipp@redhat.com>
- remove unnecessary echo statement

* Fri Oct 15 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.1.7 unstable

* Thu Oct 14 2004 Nils Philippsen <nphilipp@redhat.com>
- catch wrong values of bpp in BMP plugin (#135675), don't forget 1bpp and
  24bpp (d'oh)

* Thu Sep 30 2004 Christopher Aillon <caillon@redhat.com>
- PreReq desktop-file-utils >= 0.9

* Sun Sep 26 2004 Nils Philippsen <nphilipp@redhat.com>
- fix post/postun requirements

* Sat Sep 25 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0.5

* Thu Sep 16 2004 Nils Philippsen <nphilipp@redhat.com>
- rename desktop title (#132548)

* Thu Aug 26 2004 Nils Philippsen <nphilipp@redhat.com>
- add MimeType to desktop file
- run update-desktop-database in %%post/%%postun
- don't make stunts with -32 or -64 postfixed binaries anymore
- require /sbin/ldconfig and /usr/bin/update-desktop-database

* Tue Aug 10 2004 Nils Philippsen <nphilipp@redhat.com>
- build requires libwmf-devel

* Fri Aug 06 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0.4

* Wed Aug 04 2004 Nils Philippsen <nphilipp@redhat.com>
- rebuild to pick up new libcroco

* Thu Jul 22 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0.3
- buildreq gtk2-devel >= 2.4.0
- use -32 or -64 postfixed binaries if available

* Fri Jul 02 2004 Nils Philippsen <nphilipp@redhat.com>
- use included desktop (#126723), application-registry, mime-info and
  icon files
- remove perl cruft (Gimp-Perl is an external package now)
- further spec file cleaning

* Thu Jun 24 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0.2
- fix summary (#126682)

* Tue Jun 22 2004 Nils Philippsen <nphilipp@redhat.com>
- build with gcc34 patch (sopwith)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon May 31 2004 Nils Philippsen <nphilipp@redhat.com>
- rebuild for Rawhide

* Wed May 26 2004 Nils Philippsen <nphilipp@redhat.com>
- add libjpeg-devel to BuildRequires (#121236)
- spit out slightly more informative help message if gimp-help is missing
  (#124307)

* Fri May 21 2004 Matthias Clasen <mclasen@redhat.com>
- rebuild

* Wed Apr 21 2004 Seth Nickell <snickell@redhat.com>
- Rename menu entry for .desktop file to "GIMP Image Editor"

* Tue Apr 20 2004 Nils Philippsen <nphilipp@redhat.com>
- update BuildRequires/Requires (#121236)

* Wed Apr 14 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0.1

* Sun Mar 28 2004 Nils Philippsen <nphilipp@redhat.com>
- fix slide script-fu

* Sat Mar 27 2004 Nils Philippsen <nphilipp@redhat.com>
- bump some Build/Requires: versions
- change desktop file to actually run gimp-2.0

* Wed Mar 24 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0.0

* Tue Mar 23 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0rc1

* Wed Mar 17 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0pre4

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Feb 18 2004 Tim Waugh <twaugh@redhat.com>
- Added epoch to gimp-perl obsoletes tag.

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Nils Philippsen <nphilipp@redhat.com>
- fix typo in %%_enable_print macro
- install convenience symlinks (gimp, gimp-remote, gimptool)

* Sun Feb 08 2004 Nils Philippsen <nphilipp@redhat.com>
- require gtk2, glib2 >= 2.3.0, pango >= 1.3.0

* Fri Feb 06 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0pre3
- update buildroot patch
- enable building static libs (old default)
- have '--define'able enable_*
- disable building of print plugin, it's in another package

* Fri Jan 30 2004 Nils Philippsen <nphilipp@redhat.com>
- rebuild against new libcroco

* Sat Jan 24 2004 Nils Philippsen <nphilipp@redhat.com>
- require %%{epoch}:%%{version}-%%{release} of base package in sub packages
- rather use %%{?smp_mflags} to actually exploit SMP build systems

* Fri Jan 23 2004 Nils Philippsen <nphilipp@redhat.com>
- set epoch to 1 to upgrade old gimp rpms
- obsolete gimp2-devel, gimp-beta-devel to allow upgrade of 3rd party repo
  packages, gimp-perl to upgrade old package

* Fri Jan 23 2004 Nils Philippsen <nphilipp@redhat.com>
- fix binary name in desktop file ("gimp-1.3" until gimp-2.0 becomes final, to
  allow coexistence with old gimp-1.x packages)
- system intltool buildrequires perl-XML-Parser, work around that, yay

* Thu Jan 22 2004 Nils Philippsen <nphilipp@redhat.com>
- build as gimp, not gimp-beta
- remove all the beta blurbs
- fix automake dependency
- fix libtool usage

* Tue Jan 20 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0pre2

* Sun Jan 11 2004 Nils Philippsen <nphilipp@redhat.com>
- version 2.0pre1

* Tue Nov 25 2003 Nils Philippsen <nphilipp@redhat.com>
- version 1.3.23 beta

* Fri Nov 21 2003 Nils Philippsen <nphilipp@redhat.com>
- version 1.3.22 beta

* Thu Oct 16 2003 Nils Philippsen <nphilipp@redhat.com>
- leave gtk-doc documentation in place
- move gimptool to main package
- own some directories previously not owned

* Tue Oct 07 2003 Nils Philippsen <nphilipp@redhat.com>
- version 1.3.21 beta

* Thu Sep 11 2003 Nils Philippsen <nphilipp@redhat.com>
- version 1.3.20 beta

* Mon Aug 11 2003 Nils Philippsen <nphilipp@redhat.com>
- version 1.3.18 beta

* Thu Jul 10 2003 Nils Philippsen <nphilipp@redhat.com>
- don't specify file modes with defattr

* Wed Jul 09 2003 Nils Philippsen <nphilipp@redhat.com>
- use system libtool

* Fri Jul 04 2003 Nils Philippsen <nils@redhat.de>
- version 1.3.16 beta
- update buildroot patch

* Tue Mar 25 2003 Nils Philippsen <nils@lisas.de>
- version 1.3.13 beta
- use automake-1.7

* Tue Feb 18 2003 Nils Philippsen <nils@lisas.de>
- version 1.3.12 beta

* Fri Oct 25 2002 Nils Philippsen <nils@lisas.de>
- version 1.3.9 beta
- move desktop file to /usr/share/applications

* Wed Aug 28 2002 Nils Philippsen <nils@redhat.de>
- version 1.3.8 beta
- update and fix buildroot patch, don't run automake/autoconf

* Mon Jul 08 2002 Nils Philippsen <nils@redhat.de>
- version 1.3.7 beta
- use automake 1.5 and autoconf 2.53

* Fri Mar 15 2002 Nils Philippsen <nils@redhat.de>
- version 1.3.4 beta

* Thu Jul 19 2001 Tim Powers <timp@redhat.com>
- remove the perl temp files to pacify rpmlint

* Tue Jun 19 2001 Matt Wilson <msw@redhat.com>
- added versioned requires to gimp-devel and gimp-perl

* Tue Apr  3 2001 Matt Wilson <msw@redhat.com>
- added gimp-1.2.1-locale.patch, which I've checked in to gimp CVS, to
  correctly set up the locale in plug-ins (#34214)

* Mon Apr  2 2001 Preston Brown <pbrown@redhat.com>
- some gimp-perl files weren't defattr'd (#34325)

* Fri Mar 30 2001 Trond Eivind Glomsrd <teg@redhat.com>
- Don't include embedxpm, as it depends on a non-included perl module (#=33249)
- move gimpdoc and xcftopnm to gimp-perl, as they are dependant on the perl Gimp
  module

* Thu Mar 01 2001 Owen Taylor <otaylor@redhat.com>
- Rebuild for GTK+-1.2.9 include paths

* Mon Jan 22 2001 Matt Wilson <msw@redhat.com>
- 1.2.1

* Mon Dec 25 2000 Matt Wilson <msw@redhat.com>
- 1.2.0

* Wed Dec 20 2000 Matt Wilson <msw@redhat.com>
- 1.1.31

* Thu Dec 14 2000 Matt Wilson <msw@redhat.com>
- 1.1.30
- merge changes from CVS into rpm-4.0 style spec file
- removed va_arg patch

* Mon Aug 21 2000 Matt Wilson <msw@redhat.com>
- 1.1.25

* Fri Aug 11 2000 Jonathan Blandford <jrb@redhat.com>
- Up Epoch and release

* Tue Aug  8 2000 Matt Wilson <msw@redhat.com>
- fixed directory mode on %%{_defaultdocdir}/gimp-%%{version}

* Wed Aug  2 2000 Matt Wilson <msw@redhat.com>
- rebuild against new libpng

* Mon Jul 31 2000 Matt Wilson <msw@redhat.com>
- muck with modules filelist generation to avoid getting files owned by
  two packages

* Mon Jul 17 2000 Matt Wilson <msw@redhat.com>
- disable aa plugin
- moved the group back to Applications/Multimedia
- added desktop entry back into the file list

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Fri Jul  1 2000 Matt Wilson <msw@redhat.com>
- 1.1.24

* Sat Jun 17 2000 Matt Wilson <msw@redhat.com>
- use root, not bin for the default owner.

* Fri Jun 16 2000 Preston Brown <pbrown@redhat.com>
- add back missing system .desktop entry

* Sat Jun 10 2000 Matt Wilson <msw@redhat.com>
- rebuilt against fixed gcc

* Mon Jun  5 2000 Matt Wilson <msw@redhat.com>
- defattr for gimp-perl

* Sun Jun  4 2000 Matt Wilson <msw@redhat.com>
- drop out all of \.a$ from the main package list

* Sat Jun  3 2000 Matt Wilson <msw@redhat.com>
- 1.1.23
- use __NO_MATH_INLINES for now on ix86
- massive FHS surgery

* Tue May 16 2000 Matt Wilson <msw@redhat.com>
- 1.1.22

* Mon Apr 24 2000 Matt Wilson <msw@redhat.com>
- 1.1.20

* Fri Apr 14 2000 Matt Wilson <msw@redhat.com>
- include subdirs in the help find
- remove gimp-help-files generation
- both gimp and gimp-perl own prefix/lib/gimp/1.1/plug-ins
- both gimp and gimp-devel own prefix/lib/gimp/1.1/modules

* Thu Apr 13 2000 Matt Wilson <msw@redhat.com>
- 1.1.19
- get all .mo files

* Wed Jan 19 2000 Gregory McLean <gregm@comstar.net>
- Version 1.1.15

* Wed Dec 22 1999 Gregory McLean <gregm@comstar.net>
- Version 1.1.14
- Added some auto %files section generation scriptlets


